@@ -28,5 +28,5 @@ def test_all_four():
     is_four(2)
     should_be_False = is_four(3)
     should_be_True = is_four(4)
-    print("should_be_True={}".format(should_be_True))
-    print("should_be_False={}".format(should_be_False))
+    print(f"should_be_True={should_be_True}")
+    print(f"should_be_False={should_be_False}")
